Crate remtools

source ·
Little snippets of code that i find myself needing often, so i compiled them into a crate.

Main features are the join macro and the FancyText / colors system for text formatting.

Modules

  • Color codes and formatting chars. Used in conjunction with the FancyText trait

Macros

  • Joins an array of elements
  • ?: operator in languages like Java

Structs

Enums

  • Separate a field from the parent object

Traits

  • Allows String and &str to have formatting applied